@@ -17,7 +17,7 @@ pub fn cmd() -> Cmd {
         ])
 }
 
-pub fn exec(config: &Config, args: &clap::ArgMatches) -> CmdResult {
+pub fn exec(config: &Config, args: &clap::ArgMatches) -> CmdResult<()> {
     let app_name = args.value_of("name").map(|app_name| app_name.to_owned());
     let verbose = args.is_present("verbose");
     let debug = args.is_present("debug");
