@@ -1,10 +1,8 @@
-use crate::commands::remove::RemoveOptions;
-use crate::print::Printer;
-use crate::Config;
+use crate::{commands::remove::RemoveOptions, config::Config, errors::CmdResult, print::Printer};
 use std::fs;
 use std::path::PathBuf;
 
-pub fn do_remove(path_buf: PathBuf, printer: &mut Printer) -> anyhow::Result<()> {
+pub fn do_remove(path_buf: PathBuf, printer: &mut Printer) -> CmdResult<()> {
     let path = path_buf.as_path();
     printer.status(&"Remove", path.to_str().unwrap())?;
     match path.exists() {
@@ -15,7 +13,7 @@ pub fn do_remove(path_buf: PathBuf, printer: &mut Printer) -> anyhow::Result<()>
     Ok(())
 }
 
-pub fn do_exec(config: &Config, opts: &RemoveOptions) -> anyhow::Result<()> {
+pub fn do_exec(config: &Config, opts: &RemoveOptions) -> CmdResult<()> {
     let mut printer = Printer::new();
     do_remove(config.get_app_directory(opts.get_app_name()), &mut printer)
 }
